#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_SQRT_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_SQRT_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/simd/sqrt.hpp>

#endif
